==> pnetlib-0.6.0.1.tar.gz: pnetlib-0.6.0.1/System.Xml/Serialization/XmlArrayAttribute.cs <==
/*
 * XmlArrayAttribute.cs - Implementation of the
 *			"System.Xml.Serialization.XmlArrayAttribute" class.
 *
 * Copyright (C) 2003  Free Software Foundation, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

namespace System.Xml.Serialization
{

#if !ECMA_COMPAT

using System;
using System.Xml;
using System.Xml.Schema;

[AttributeUsage(AttributeTargets.Property |
                AttributeTargets.Field |
                AttributeTargets.Parameter |
                AttributeTargets.ReturnValue)]
public class XmlArrayAttribute : Attribute
{
	// Internal state.
	private String elementName;
	private XmlSchemaForm form;
	private bool isNullable;
	private String nspace;

	// Constructors.
	public XmlArrayAttribute()
			: base()
			{
				this.elementName = "";
				this.form = XmlSchemaForm.None;
				this.isNullable = false;
				this.nspace = null;
			}
	public XmlArrayAttribute(String elementName)
			: base()
			{
				if (elementName == null) { elementName = ""; }
				this.elementName = elementName;
				this.form = XmlSchemaForm.None;
				this.isNullable = false;
				this.nspace = null;
			}

	// Properties.
	public String ElementName
			{
				get { return elementName; }
				set
				{
					if (value == null) { value = ""; }
					elementName = value;
				}
			}
	public XmlSchemaForm Form
			{
				get { return form; }
				set { form = value; }
			}
	public bool IsNullable
			{
				get { return isNullable; }
				set { isNullable = value; }
			}
	public String Namespace
			{
				get { return nspace; }
				set { nspace = value; }
			}

}; // class XmlArrayAttribute

#endif // !ECMA_COMPAT

}; // namespace System.Xml.Serialization

==> pnetlib-0.6.6.tar.gz: pnetlib-0.6.6/System.Xml/Serialization/XmlArrayAttribute.cs <==
/*
 * XmlArrayAttribute.cs - Implementation of the
 *			"System.Xml.Serialization.XmlArrayAttribute" class.
 *
 * Copyright (C) 2003  Free Software Foundation, Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

namespace System.Xml.Serialization
{

#if !ECMA_COMPAT

using System;
using System.Xml;
using System.Xml.Schema;

[AttributeUsage(AttributeTargets.Property |
                AttributeTargets.Field |
                AttributeTargets.Parameter |
                AttributeTargets.ReturnValue,
                AllowMultiple=false)]
public class XmlArrayAttribute : Attribute
{
	// Internal state.
	private String elementName;
	private XmlSchemaForm form;
	private bool isNullable;
	private String nspace;

	// Constructors.
	public XmlArrayAttribute()
			: base()
			{
				this.elementName = "";
				this.form = XmlSchemaForm.None;
				this.isNullable = false;
				this.nspace = null;
			}
	public XmlArrayAttribute(String elementName)
			: base()
			{
				if (elementName == null) { elementName = ""; }
				this.elementName = elementName;
				this.form = XmlSchemaForm.None;
				this.isNullable = false;
				this.nspace = null;
			}

	// Properties.
	public String ElementName
			{
				get { return elementName; }
				set
				{
					if (value == null) { value = ""; }
					elementName = value;
				}
			}
	public XmlSchemaForm Form
			{
				get { return form; }
				set { form = value; }
			}
	public bool IsNullable
			{
				get { return isNullable; }
				set { isNullable = value; }
			}
	public String Namespace
			{
				get { return nspace; }
				set { nspace = value; }
			}

}; // class XmlArrayAttribute

#endif // !ECMA_COMPAT

}; // namespace System.Xml.Serialization
